      SUBROUTINE REZEST_FDC_CDC(P, LAMBDA, M,
     X     DP_OVER_P, DPHI_TOT, DTHETA_TOT)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C This routine estimates the resolution in GlueX for charged particles
C in tranverse momentum, azimuthal angle, and polar angle.
C
C Input arguments, all REAL*4
C
C     P        Magnitude of total momentum (GeV/c)
C     LAMBDA   Dip angle, difference in polar angle in lab between track
C              and pi/2 (i. e., 90 degrees) (radians)
C     M        Mass of the particle (GeV/c^2)
C
C Output arguments, all REAL*4
C
C     DP_OVER_P  Relative resolution in transvers momentum ("sigma_{p_t}/p_t")
C     DPHI_TOT   Resolution in azimuthal angle ("sigma_phi")
C     DTHETA_TOT Resolution in polar angle ("sigma_theta")
C
C The routine combines the measurements in the FDC and CDC where
C appropriate. Parameters describing the geometry and materials are
C defined in the routine REZEST_COMPONENTS which appears below.
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

      REAL*4 P, LAMBDA, M
      REAL*4 DP_OVER_P, DPHI_TOT, DTHETA_TOT
      REAL*4 DK_MS(2), DK_RES(2), DK(2)
      REAL*4 DPHI_MS(2), DPHI_RES(2), DPHI_K(2), DPHI(2)
      REAL*4 DTHETA_MS(2), DTHETA_RES(2), DTHETA(2)
      CALL REZEST_COMPONENTS(P, LAMBDA, M,
     X     DP_OVER_P, DPHI_TOT, DTHETA_TOT,
     X     DK_MS, DK_RES, DK,
     X     DPHI_MS, DPHI_RES, DPHI_K, DPHI,
     X     DTHETA_MS, DTHETA_RES, DTHETA)
      RETURN
      END

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

      SUBROUTINE REZEST_COMPONENTS(P, LAMBDA, M,
     X     DP_OVER_P, DPHI_TOT, DTHETA_TOT,
     X     DK_MS, DK_RES, DK,
     X     DPHI_MS, DPHI_RES, DPHI_K, DPHI,
     X     DTHETA_MS, DTHETA_RES, DTHETA)

      IMPLICIT NONE
      CHARACTER*3 DET(2)
      REAL*4 B, EPSILON(2), N_RL(2), N_RL_FRONT(2), LAMBDA, L(2),
     X     N_M_EFF(2), N_M_EFF_POLAR(2), M, P, R_M(2), STEREO
      REAL*4 DK_MS(2), DK_RES(2), DK(2)
      REAL*4 DPHI_MS(2), DPHI_RES(2), DPHI_K(2), DPHI(2)
      REAL*4 DTHETA_MS(2), DTHETA_RES(2), DTHETA(2)
      REAL*4 DK_INV2TOT, DPHI_INV2TOT, DTHETA_INV2TOT
      REAL*4 DK_TOT, DPHI_TOT, DTHETA_TOT
      REAL*4 PT, K, DP_OVER_P, N_M(2), N_M_POLAR(2), Z_LENGTH_CDC
      REAL*4 LAMBDA_CDC, LAMBDA_CDC_INNER
      REAL*4 LAMBDA_FDC_FRONT, LAMBDA_FDC_BACK
      REAL*4 PIOVER2, L_EFF(2), Z_MIN_FDC, Z_MAX_FDC
      REAL*4 R_MIN_CDC, R_MAX_CDC, R_MAX_FDC, N_RL_EFF(2)
      INTEGER*4 I

      DATA PIOVER2 /1.5707963/
      DATA B /1.74/
      DATA EPSILON /0.00015, 0.00020/
      DATA N_RL /0.03437, 0.01437/
      DATA N_RL_FRONT /0.0212, 0.0000/
      DATA R_M /.377475, 0.293/
      DATA N_M /23, 24/
      DATA N_M_POLAR /10, 24/
      DATA DET /'CDC', 'FDC'/
      DATA R_MIN_CDC /0.10960/, R_MAX_CDC /0.56534/

      STEREO = 6.0*3.14159/180.0

      R_MAX_FDC = R_MAX_CDC
      Z_MIN_FDC = 1.90 - 0.65
      Z_MAX_FDC = 3.57 - 0.65
      Z_LENGTH_CDC = 1.67 - 0.65
      L(1) = R_MAX_CDC - R_MIN_CDC
      L(2) = Z_MAX_FDC - Z_MIN_FDC
      LAMBDA_CDC = ATAN(Z_LENGTH_CDC/R_MAX_CDC)
      LAMBDA_CDC_INNER = ATAN(Z_LENGTH_CDC/R_MIN_CDC)
      LAMBDA_FDC_FRONT = ATAN(Z_MIN_FDC/R_MAX_FDC)
      LAMBDA_FDC_BACK = ATAN(Z_MAX_FDC/R_MAX_FDC)

      IF (LAMBDA .GE. LAMBDA_CDC_INNER) THEN
         N_M_EFF(1) = 0.0;
         N_M_EFF_POLAR(1) = 0.0;
      ELSE IF (LAMBDA .GE. LAMBDA_CDC) THEN
         L_EFF(1) = Z_LENGTH_CDC*TAN(PIOVER2 - LAMBDA) - R_MIN_CDC
         N_M_EFF(1) = N_M(1)*L_EFF(1)/L(1)
         N_M_EFF_POLAR(1) = N_M_POLAR(1)*L_EFF(1)/L(1)
         N_RL_EFF(1) = N_RL(1)*L_EFF(1)/L(1)
      ELSE
         N_M_EFF(1) = N_M(1)
         N_M_EFF_POLAR(1) = N_M_POLAR(1)
         L_EFF(1) = L(1)
         N_RL_EFF(1) = N_RL(1);
      END IF

      IF (LAMBDA .LT. LAMBDA_FDC_FRONT) THEN
         N_M_EFF(2) = 0.0
         N_M_EFF_POLAR(2) = 0.0
      ELSE IF (LAMBDA .LT. LAMBDA_FDC_BACK) THEN
         L_EFF(2) = R_MAX_FDC*TAN(LAMBDA) - Z_MIN_FDC
         N_M_EFF(2) = N_M(2)*L_EFF(2)/L(2)
         N_M_EFF_POLAR(2) = N_M_POLAR(2)*L_EFF(2)/L(2)
         N_RL_EFF(2) = N_RL(2)*L_EFF(2)/L(2)
      ELSE
         L_EFF(2) = L(2)
         N_M_EFF(2) = N_M(2)
         N_M_EFF_POLAR(2) = N_M_POLAR(2)
         N_RL_EFF(2) = N_RL(2)
      END IF

      DK_INV2TOT = 0.0
      DPHI_INV2TOT = 0.0
      DTHETA_INV2TOT = 0.0
      DO I = 1, 2
C         WRITE (6, *) DET(I)
         CALL REZEST_CURVE(DET(I), LAMBDA, L_EFF(I), EPSILON(I),
     X        N_M_EFF(I), P, M, N_RL_EFF(I), B,
     X        DK_MS(I), DK_RES(I), DK(I))
C         WRITE (6, *) 'curve', DK_MS(I), DK_RES(I), DK(I)
         DK_INV2TOT = DK_INV2TOT + 1.0/(DK(I)*DK(I))
         CALL REZEST_AZIMUTH(DET(I), LAMBDA, L_EFF(I), EPSILON(I),
     X        N_M_EFF(I), P, M, N_RL_EFF(I), N_RL_FRONT(I), B,
     X        R_M(I), DK(I),
     X        DPHI_MS(I), DPHI_RES(I), DPHI_K(I), DPHI(I))
C         WRITE (6, *) 'azimu', DPHI_MS(I), DPHI_RES(I), DPHI_K(I),
C     X        DPHI(I)
         DPHI_INV2TOT = DPHI_INV2TOT + 1.0/(DPHI(I)*DPHI(I))
         CALL REZEST_POLAR(DET(I), LAMBDA, L_EFF(I), EPSILON(I),
     X        STEREO, N_M_EFF_POLAR(I), P, M, N_RL_EFF(I),
     X        N_RL_FRONT(I), DTHETA_MS(I), DTHETA_RES(I), DTHETA(I))
C         WRITE (6, *) 'polar', DTHETA_MS(I), DTHETA_RES(I), DTHETA(I)
         DTHETA_INV2TOT = DTHETA_INV2TOT + 1.0/(DTHETA(I)*DTHETA(I))
         PT = P*COS(LAMBDA)
      END DO
      DK_TOT = 1.0/SQRT(DK_INV2TOT)
      DPHI_TOT = 1.0/SQRT(DPHI_INV2TOT)
      DTHETA_TOT = 1.0/SQRT(DTHETA_INV2TOT)
      PT = P*COS(LAMBDA)
      K = 0.3*B/PT
      DP_OVER_P = DK_TOT/K

      RETURN
      END

C END OF FORTRAN CODE
